==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/worldgen/AllPlacedFeatures.java <==
package com.zurrtum.create.infrastructure.worldgen;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.minecraft.class_1959;
import net.minecraft.class_2378;
import net.minecraft.class_2893;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_5363;
import net.minecraft.class_5455;
import net.minecraft.class_6796;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7924;

import static com.zurrtum.create.Create.MOD_ID;

public class AllPlacedFeatures {
    public static final class_5321<class_6796> ZINC_ORE = register("zinc_ore");
    public static final class_5321<class_6796> STRIATED_ORES_OVERWORLD = register("striated_ores_overworld");
    public static final class_5321<class_6796> STRIATED_ORES_NETHER = register("striated_ores_nether");

    public static class_5321<class_6796> register(String id) {
        return class_5321.method_29179(class_7924.field_41245, class_2960.method_60655(MOD_ID, id));
    }

    public static void register(class_5455 registryManager) {
        class_2378<class_6796> placed = registryManager.method_30530(class_7924.field_41245);
        class_6880<class_6796> zincOverworld = placed.method_46746(AllPlacedFeatures.ZINC_ORE).orElseThrow();
        class_6880<class_6796> striatedOverworld = placed.method_46746(AllPlacedFeatures.STRIATED_ORES_OVERWORLD).orElseThrow();
        class_6880<class_6796> striatedNether = placed.method_46746(AllPlacedFeatures.STRIATED_ORES_NETHER).orElseThrow();
        int index = class_2893.class_2895.field_13176.ordinal();
        addFeature(registryManager, class_5363.field_25412, index, List.of(zincOverworld, striatedOverworld));
        addFeature(registryManager, class_5363.field_25413, index, List.of(striatedNether));
    }

    private static void addFeature(
        class_5455 registryManager,
        class_5321<class_5363> options,
        int index,
        List<class_6880<class_6796>> entries
    ) {
        registryManager.method_30530(class_7924.field_41224).method_29107(options).comp_1013().method_12098().method_28443().stream()
            .map(class_6880::comp_349).map(class_1959::method_30970).forEach(settings -> {
                if (!(settings.field_26416 instanceof ArrayList<class_6885<class_6796>>)) {
                    settings.field_26416 = new ArrayList<>(settings.field_26416);
                }
                List<class_6885<class_6796>> features = settings.field_26416;
                int size = features.size();
                if (size <= index) {
                    for (int i = size; i < index; i++) {
                        features.add(class_6885.method_40242(Collections.emptyList()));
                    }
                    features.add(class_6885.method_40242(entries));
                } else {
                    class_6885<class_6796> values = features.get(index);
                    if (values != null) {
                        List<class_6880<class_6796>> list = new ArrayList<>(values.method_40239().toList());
                        list.addAll(entries);
                        values = class_6885.method_40242(list);
                    } else {
                        values = class_6885.method_40242(entries);
                    }
                    features.set(index, values);
                }
            });
    }

    public static void register() {
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/worldgen/AllPlacedFeatures.java <==
package com.zurrtum.create.infrastructure.worldgen;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.minecraft.class_1959;
import net.minecraft.class_2378;
import net.minecraft.class_2893;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_5363;
import net.minecraft.class_5455;
import net.minecraft.class_6796;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7924;

import static com.zurrtum.create.Create.MOD_ID;

public class AllPlacedFeatures {
    public static final class_5321<class_6796> ZINC_ORE = register("zinc_ore");
    public static final class_5321<class_6796> STRIATED_ORES_OVERWORLD = register("striated_ores_overworld");
    public static final class_5321<class_6796> STRIATED_ORES_NETHER = register("striated_ores_nether");

    public static class_5321<class_6796> register(String id) {
        return class_5321.method_29179(class_7924.field_41245, class_2960.method_60655(MOD_ID, id));
    }

    public static void register(class_5455 registryManager) {
        class_2378<class_6796> placed = registryManager.method_30530(class_7924.field_41245);
        class_6880<class_6796> zincOverworld = placed.method_46746(AllPlacedFeatures.ZINC_ORE).orElseThrow();
        class_6880<class_6796> striatedOverworld = placed.method_46746(AllPlacedFeatures.STRIATED_ORES_OVERWORLD).orElseThrow();
        class_6880<class_6796> striatedNether = placed.method_46746(AllPlacedFeatures.STRIATED_ORES_NETHER).orElseThrow();
        int index = class_2893.class_2895.field_13176.ordinal();
        addFeature(registryManager, class_5363.field_25412, index, List.of(zincOverworld, striatedOverworld));
        addFeature(registryManager, class_5363.field_25413, index, List.of(striatedNether));
    }

    private static void addFeature(class_5455 registryManager, class_5321<class_5363> options, int index, List<class_6880<class_6796>> entries) {
        registryManager.method_30530(class_7924.field_41224).method_29107(options).comp_1013().method_12098().method_28443().stream()
            .map(class_6880::comp_349).map(class_1959::method_30970).forEach(settings -> {
                if (!(settings.field_26416 instanceof ArrayList<class_6885<class_6796>>)) {
                    settings.field_26416 = new ArrayList<>(settings.field_26416);
                }
                List<class_6885<class_6796>> features = settings.field_26416;
                int size = features.size();
                if (size <= index) {
                    for (int i = size; i < index; i++) {
                        features.add(class_6885.method_40242(Collections.emptyList()));
                    }
                    features.add(class_6885.method_40242(entries));
                } else {
                    class_6885<class_6796> values = features.get(index);
                    if (values != null) {
                        List<class_6880<class_6796>> list = new ArrayList<>(values.method_40239().toList());
                        list.addAll(entries);
                        values = class_6885.method_40242(list);
                    } else {
                        values = class_6885.method_40242(entries);
                    }
                    features.set(index, values);
                }
            });
    }

    public static void register() {
    }
}
